# Fast Vindex

**fast_vindex** is a faster and more flexible alternative to Dask's built-in `vindex` function, designed to improve performance when working with complex or high-dimensional array indexing.

## Installation

```bash
pip install fast_vindex
```

## Documentation

```bash
sphinx-build -M html docs docs/_build/
rm -rf docs/_build/
```